@@ -22,7 +22,7 @@ use Yote::ObjProvider;
 
 use vars qw($VERSION);
 
-$VERSION = '0.083';
+$VERSION = '0.085';
 
 
 my( %prid2result, $singleton );
@@ -225,6 +225,7 @@ sub process_http_request {
 	} 
 	if( open( IN, "<$root/$dest" ) ) {
 	    print $soc "HTTP/1.0 200 OK\015\012";
+	    my $binary = 0;
 	    if( $dest =~ /\.js$/i ) {
 		push( @return_headers, "Content-Type: text/javascript" );
 	    }
@@ -234,6 +235,9 @@ sub process_http_request {
 	    elsif( $dest =~ /\.(jpg|gif|png|jpeg)$/i ) {
 		push( @return_headers, "Content-Type: image/$1" );
 	    }
+	    elsif( $dest =~ /\.(tar|gz|zip|bz2)$/i ) {
+		push( @return_headers, "Content-Type: image/$1" );
+	    }
 	    else {
 		push( @return_headers, "Content-Type: text/html" );
 	    }
@@ -243,8 +247,10 @@ sub process_http_request {
 	    my $size = -s "<$root/$dest";
 	    push( @return_headers, "Content-length: $size" );
 	    push( @return_headers,  "Access-Control-Allow-Origin: *" );
-            while(<IN>) {
-                print $soc $_;
+
+	    my $buf;
+            while( read( IN,$buf, 8 * 2**10 ) ) {
+                print $soc $buf;
             }
             close( IN );
 	    accesslog( "200 : $dest");
@@ -421,6 +427,9 @@ sub _process_command {
         my $app         = Yote::ObjProvider::fetch( $app_id ) || Yote::YoteRoot::fetch_root();
 
         my $data        = _translate_data( from_json( MIME::Base64::decode( $command->{d} ) )->{d} );
+	
+	accesslog( "   DATA : " . Data::Dumper->Dump( [ $data ] ) );
+
         my $login       = $app->token_login( $command->{t}, undef, $command->{e} );
 	my $guest_token = $command->{gt};
 	$command->{e}{GUEST_TOKEN} = $guest_token;
@@ -433,6 +442,8 @@ sub _process_command {
 
         my $app_object = Yote::ObjProvider::fetch( $obj_id ) || $app;
         my $action     = $command->{a};
+	
+	die "Access Error" if $action =~ /^([gs]et|add_(once_)?to_|remove_(all_)?from)_/; # set may not be called directly on an object.
         my $account;
         if( $login ) {
             $account = $app->__get_account( $login );
